@@ -2,7 +2,7 @@ import json
 import os
 import sys
 
-class easygis:
+class egis:
     def __init__(self,country):
         self.country = country
         
